@@ -42,6 +42,7 @@ from vantage6.cli.configuration_wizard import (
     configuration_wizard,
     select_configuration_questionaire
 )
+from vantage6.cli import __version__
 
 
 @click.group(name="node")
@@ -285,7 +286,7 @@ def cli_node_start(name, config, environment, system_folders, image, keep,
     info(f"Pulling latest node image '{image}'")
     try:
         # docker_client.images.pull(image)
-        pull_if_newer(image)
+        pull_if_newer(docker.from_env(), image)
 
     except Exception:
         warning(' ... alas, no dice!')
@@ -605,6 +606,36 @@ def cli_node_clean():
     info("Done!")
 
 
+#
+#   version
+#
+@cli_node.command(name='version')
+@click.option("-n", "--name", default=None, help="configuration name")
+@click.option('--system', 'system_folders', flag_value=True)
+@click.option('--user', 'system_folders', flag_value=False, default=N_FOL)
+def cli_node_version(name, system_folders):
+    """Returns current version of vantage6 services installed."""
+
+    client = docker.from_env()
+    check_if_docker_deamon_is_running(client)
+
+    running_nodes = client.containers.list(
+        filters={"label": f"{APPNAME}-type=node"})
+    running_node_names = [node.name for node in running_nodes]
+
+    if not name:
+        name = q.select("Select the node you wish to inspect:",
+                        choices=running_node_names).ask()
+    else:
+        post_fix = "system" if system_folders else "user"
+        name = f"{APPNAME}-{name}-{post_fix}"
+
+    if name in running_node_names:
+        container = client.containers.get(name)
+        version = container.exec_run(cmd='vnode-local version', stdout = True)
+        click.echo({"node": version.output.decode('utf-8'), "cli":__version__})
+
+
 def print_log_worker(logs_stream):
     for log in logs_stream:
         print(log.decode(STRING_ENCODING), end="")
